=======
History
=======

1.4.0 (2022-01-10)
------------------

* Drop Python 3.6 support.

* Remove upper bound on Flake8 version.

1.3.0 (2021-10-11)
------------------

* Support Flake8 4.

* Add type hints (ironically).

1.2.0 (2021-05-10)
------------------

* Support Python 3.10.

* Stop distributing tests to reduce package size. Tests are not intended to be
  run outside of the tox setup in the repository. Repackagers can use GitHub's
  tarballs per tag.

1.1.1 (2020-12-19)
------------------

* Improved installation instructions in README.

1.1.0 (2020-12-13)
------------------

* Drop Python 3.5 support.
* Support Python 3.9.
* Move license from ISC to MIT License.

1.0.0 (2019-11-19)
------------------

* First release on PyPI.
* ``NT001`` rule that complains about type annotations.
